package ru.myitschool.work.ui.main

import android.os.Bundle
import android.view.View
import android.widget.Toast
import androidx.fragment.app.Fragment
import androidx.lifecycle.lifecycleScope
import kotlinx.coroutines.launch
import retrofit2.Retrofit
import retrofit2.converter.gson.GsonConverterFactory
import ru.myitschool.work.R
import ru.myitschool.work.api.ApiService
import ru.myitschool.work.api.ToggleAccessRequest
import ru.myitschool.work.core.Constants
import ru.myitschool.work.databinding.FragmentAdminBinding

class AdminFragment : Fragment(R.layout.fragment_admin) {
    private var _binding: FragmentAdminBinding? = null
    private val binding get() = _binding!!

    private val apiService: ApiService by lazy {
        Retrofit.Builder()
            .baseUrl(Constants.SERVER_ADDRESS)
            .addConverterFactory(GsonConverterFactory.create())
            .build()
            .create(ApiService::class.java)
    }
//.
    private var isAccessBlocked: Boolean = false // Переменная для отслеживания состояния доступа

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        _binding = FragmentAdminBinding.bind(view)

        setupUI()
    }

    private fun setupUI() {
        binding.viewEmployeeInfo.setOnClickListener {
            val login = binding.employeeLogin.text.toString()
            if (login.isNotEmpty()) {
                fetchEmployeeInfo(login)
            } else {
                Toast.makeText(requireContext(), "Введите логин сотрудника", Toast.LENGTH_SHORT).show()
            }
        }

        binding.toggleAccess.setOnClickListener {
            val login = binding.employeeLogin.text.toString()
            if (login.isNotEmpty()) {
                // Определяем действие на основе текущего состояния доступа
                val action = if (isAccessBlocked) "unblock" else "block"
                toggleEmployeeAccess(login, action)
            } else {
                Toast.makeText(requireContext(), "Введите логин сотрудника", Toast.LENGTH_SHORT).show()
            }
        }
    }

    private fun fetchEmployeeInfo(login: String) {
        lifecycleScope.launch {
            try {
                val response = apiService.getEmployeeInfo(login)
                if (response.isSuccessful) {
                    val employeeData = response.body()
                    employeeData?.let {
                        binding.employeeInfo.text = "Имя: ${it.name}, Должность: ${it.position}, Последний визит: ${it.lastVisit}"
                        binding.employeeInfo.visibility = View.VISIBLE
                        binding.toggleAccess.visibility = View.VISIBLE
                        // Здесь можно установить состояние доступа, если оно доступно
                        isAccessBlocked = false // Предположим, что доступ не заблокирован по умолчанию
                    }
                } else {
                    Toast.makeText(requireContext(), "Ошибка получения данных", Toast.LENGTH_SHORT).show()
                }
            } catch (e: Exception) {
                e.printStackTrace()
                Toast.makeText(requireContext(), "Ошибка сети", Toast.LENGTH_SHORT).show()
            }
        }
    }

    private fun toggleEmployeeAccess(login: String, action: String) {
        val request = ToggleAccessRequest(login, action)

        lifecycleScope.launch {
            try {
                val response = apiService.toggleAccess(request)
                if (response.isSuccessful) {
                    isAccessBlocked = !isAccessBlocked // Переключаем состояние доступа
                    val message = if (action == "block") "Доступ заблокирован" else "Доступ разблокирован"
                    Toast.makeText(requireContext(), message, Toast.LENGTH_SHORT).show()
                } else {
                    Toast.makeText(requireContext(), "Ошибка изменения доступа", Toast.LENGTH_SHORT).show()
                }
            } catch (e: Exception) {
                e.printStackTrace()
                Toast.makeText(requireContext(), "Ошибка сети", Toast.LENGTH_SHORT).show()
            }
        }
    }

    override fun onDestroyView() {
        _binding = null // Освобождаем binding, когда представление уничтожается
        super.onDestroyView()
    }
}